@@ -8,15 +8,15 @@ import core_explore_example_app.permissions.discover as discover
 
 
 class ExploreExampleAppConfig(AppConfig):
-    """ Core application settings
-    """
-    name = 'core_explore_example_app'
+    """Core application settings"""
+
+    name = "core_explore_example_app"
 
     def ready(self):
-        """ Runs when the app is ready
+        """Runs when the app is ready
 
         Returns:
 
         """
-        if 'migrate' not in sys.argv:
+        if "migrate" not in sys.argv:
             discover.init_permissions(self.apps)
